@@ -53,6 +53,10 @@ PNACL_RELEASE_OPTIONS = {
     'CCFLAGS':'-O2'
 }
 
+PNACL_DEBUG_OPTIONS = {
+    'CCFLAGS':'-g'
+}
+
 PNACL_STATIC_LIB_OPTIONS = {
     'CCFLAGS':['-fdata-sections','-ffunction-sections'],
 }
