@@ -80,8 +80,8 @@ def download_lint_script():
         bbricks.output.abort_exec("error: could not download 'cpplint.py' check your internet connection")
 
 def setup_scons_lint(scons_env, target):
-
-    if distutils.spawn.find_executable('cpplint.py') is None:
+    cpplint_path = distutils.spawn.find_executable('cpplint.py')
+    if cpplint_path is None:
         bbricks.output.abort_exec("error: you do not have cpplint.py installed in your PATH. Download from: http://google-styleguide.googlecode.com")
 
     scons_env.bbricks_target = target
@@ -96,7 +96,7 @@ def setup_scons_lint(scons_env, target):
 
     scons_env.Append(BUILDERS={'Lint': linter})
     scons_env["PYTHON"] = sys.executable
-    scons_env["LINT"] = "cpplint.py"
+    scons_env["LINT"] = cpplint_path
 
     lint_options = ["--verbose=3"]
 
